namespace efl { namespace input { 
inline ::efl::eolian::return_traits<Efl_Input_Device_Class>::type Device::device_type_get() const
{
   Efl_Input_Device_Class __return_value =  ::efl_input_device_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Input_Device_Class>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::device_type_set( ::efl::eolian::in_traits<Efl_Input_Device_Class>::type klass) const
{
    ::efl_input_device_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Input_Device_Class,  ::efl::eolian::in_traits<Efl_Input_Device_Class>::type>(klass));
}
inline ::efl::eolian::return_traits<Efl_Input_Device_Sub_Class>::type Device::device_subtype_get() const
{
   Efl_Input_Device_Sub_Class __return_value =  ::efl_input_device_subtype_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Input_Device_Sub_Class>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::device_subtype_set( ::efl::eolian::in_traits<Efl_Input_Device_Sub_Class>::type klass) const
{
    ::efl_input_device_subtype_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Input_Device_Sub_Class,  ::efl::eolian::in_traits<Efl_Input_Device_Sub_Class>::type>(klass));
}
inline ::efl::eolian::return_traits< ::efl::input::Device>::type Device::source_get() const
{
    ::Efl_Input_Device* __return_value =  ::efl_input_device_source_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::input::Device>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::source_set( ::efl::eolian::in_traits< ::efl::input::Device>::type src) const
{
    ::efl_input_device_source_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Input_Device*,  ::efl::eolian::in_traits< ::efl::input::Device>::type>(src));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Device::name_get() const
{
   const char * __return_value =  ::efl_input_device_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
    ::efl_input_device_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Device::description_get() const
{
   const char * __return_value =  ::efl_input_device_description_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::description_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type desc) const
{
    ::efl_input_device_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(desc));
}
inline ::efl::eolian::return_traits< ::efl::input::Device>::type Device::parent_get() const
{
    ::Efl_Input_Device* __return_value =  ::efl_input_device_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::input::Device>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace input { 
inline ::efl::eolian::return_traits<Efl_Input_Device_Class>::type Device::device_type_get() const
{
   Efl_Input_Device_Class __return_value =  ::efl_input_device_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Input_Device_Class>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::device_type_set( ::efl::eolian::in_traits<Efl_Input_Device_Class>::type klass) const
{
    ::efl_input_device_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Input_Device_Class,  ::efl::eolian::in_traits<Efl_Input_Device_Class>::type>(klass));
}
inline ::efl::eolian::return_traits<Efl_Input_Device_Sub_Class>::type Device::device_subtype_get() const
{
   Efl_Input_Device_Sub_Class __return_value =  ::efl_input_device_subtype_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Input_Device_Sub_Class>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::device_subtype_set( ::efl::eolian::in_traits<Efl_Input_Device_Sub_Class>::type klass) const
{
    ::efl_input_device_subtype_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Input_Device_Sub_Class,  ::efl::eolian::in_traits<Efl_Input_Device_Sub_Class>::type>(klass));
}
inline ::efl::eolian::return_traits< ::efl::input::Device>::type Device::source_get() const
{
    ::Efl_Input_Device* __return_value =  ::efl_input_device_source_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::input::Device>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::source_set( ::efl::eolian::in_traits< ::efl::input::Device>::type src) const
{
    ::efl_input_device_source_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Input_Device*,  ::efl::eolian::in_traits< ::efl::input::Device>::type>(src));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Device::name_get() const
{
   const char * __return_value =  ::efl_input_device_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
    ::efl_input_device_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Device::description_get() const
{
   const char * __return_value =  ::efl_input_device_description_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Device::description_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type desc) const
{
    ::efl_input_device_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(desc));
}
inline ::efl::eolian::return_traits< ::efl::input::Device>::type Device::parent_get() const
{
    ::Efl_Input_Device* __return_value =  ::efl_input_device_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::input::Device>::type>(__return_value);
}
inline efl::input::Device::operator ::efl::input::Device() const { return *static_cast< ::efl::input::Device const*>(static_cast<void const*>(this)); }
inline efl::input::Device::operator ::efl::input::Device&() { return *static_cast< ::efl::input::Device*>(static_cast<void*>(this)); }
inline efl::input::Device::operator ::efl::input::Device const&() const { return *static_cast< ::efl::input::Device const*>(static_cast<void const*>(this)); }
} } }

